.. WDOM documentation master file, created by
   sphinx-quickstart on Mon Jan 11 18:49:13 2016.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

.. note::
    This document is build by `sphinx`_ with customized `alabaster`_ theme.
    Since the theme has been modified overall by using flexbox, the page layout
    may be broken in some browsers. If you find any broken layout/page, `please
    let me know <https://github.com/miyakogi/wdom/issues>`_ which page is broken
    and which browser you use.

.. include:: ../README.rst

Contents
--------

.. toctree::
    :titlesonly:

    guide/index
    reference
    changes


Indices and tables
------------------

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

.. _sphinx: http://www.sphinx-doc.org/en/stable/
.. _alabaster: https://github.com/bitprophet/alabaster/
